@@ -4,7 +4,7 @@ import functools
 import gevent
 from gevent.server import StreamServer
 import kola
-from kola.utils import safe_call
+from kola import safe_call
 from .connection import Connection
 from .stream import GStream
 
